##
# Makefile for Apple Release Control (common)
# Wilfredo Sanchez | wsanchez@apple.com
# Copyright 1997 Apple Computer, Inc.
##
# Set these variables as needed, then include this file, then:
#
#  Project               [ UNTITLED_PROJECT ]
#  Extra_CC_Flags
#  Extra_LD_Flags
#  Extra_Environment
##

##
# Sane defaults for RC variables
##

RC_ARCHS   = ppc i386
RC_RELEASE = unknown
RC_VERSION = unknown

ifeq ($(COPY_SOURCES),YES)
SRCROOT = /tmp/$(Project)/Sources
else
SRCROOT = $(shell pwd)
endif

OBJROOT = /tmp/$(Project)/Build
SYMROOT = /tmp/$(Project)/Release/Private
DSTROOT = /tmp/$(Project)/Release/Public

##
# My variables
##

ifndef Project
Project = UNTITLED_PROJECT
endif

Sources        = $(SRCROOT)
Platforms      = $(patsubst %,%-apple-rhapsody$(RhapsodyVersion),$(RC_ARCHS:ppc=powerpc))
BuildDirectory = $(OBJROOT)

CC_Archs = $(RC_ARCHS:%=-arch %)

Environment     = CFLAGS="$(CFLAGS)"		\
		  LDFLAGS="$(LDFLAGS)"		\
		  $(Extra_Environment)

##
# InstallerPackage.make
##

Package              = $(Project)
Package_Source       = $(DSTROOT)
Package_Info         = $(SRCROOT)/$(Package).info
Package_Tiff         = $(SRCROOT)/$(Package).tiff
Package_Destination  = /tmp/$(Project)/Release
SourcePackage_Source = $(SRCROOT)

$(Package_Info): lazy_installsrc

include $(CoreOSMakefiles)/Targets/InstallerPackage.make

##
# Targets
##

.PHONY: all install installhdrs lazy_installsrc installsrc build clean

all: build

$(DSTROOT): install

install:: installhdrs build

install_headers: installhdrs

installhdrs::

lazy_installsrc::
	$(_v) if [ ! -f $(SRCROOT)/Makefile ]; then $(MAKE) installsrc; fi

install_source: installsrc

installsrc::
ifneq ($(CommonNoInstallSource),YES)
	@echo "Installing source for $(Project)..."
	$(_v) $(MKDIR) "$(SRCROOT)"
ifneq ($(wildcard $(PAX)),)
	$(_v) $(PAX) -rw . "$(SRCROOT)"
else
	$(_v) $(TAR) cf - . | (cd "$(SRCROOT)" ; $(TAR) xfp -)
endif
	$(_v) $(FIND) "$(SRCROOT)" $(Find_Cruft) | $(XARGS) $(RMDIR)
endif

build:: lazy_installsrc

clean::
	@echo "Cleaning $(Project)..."
	$(_v) $(RMDIR) "$(OBJROOT)"
	$(_v) $(RMDIR) "$(DSTROOT)"
