##
# Makefile for Apple Release Control (GNU source projects)
# Wilfredo Sanchez | wsanchez@apple.com
# Copyright 1997 Apple Computer, Inc.
##
# Set these variables as needed, then include this file, then:
#
#  Project               [ UNTITLED_PROJECT             ]
#  Install_Prefix        [ /usr                         ]
#  Install_Man           [ $(Install_Prefix)/share/man  ]
#  Install_Info          [ $(Install_Prefix)/share/info ]
#  Configure             [ configure                    ]
#  Extra_CC_Flags
#  Extra_LD_Flags
#  Extra_Configure_Flags
#  Extra_Install_Flags 
#  Extra_Environment
##

ifndef CoreOSMakefiles
CoreOSMakefiles = Makefiles
endif

include $(CoreOSMakefiles)/Standard/Standard.make
include $(CoreOSMakefiles)/ReleaseControl/Common.make

##
# My variables
##

Sources     = $(SRCROOT)/$(Project)
ConfigStamp = $(BuildDirectory)/configure-stamp

ifndef Install_Prefix
Install_Prefix = /usr
endif
ifndef Install_Man
Install_Man = $(Install_Prefix)/share/man
endif
ifndef Install_Info
Install_Info = $(Install_Prefix)/share/info
endif
RC_Install_Prefix = $(DSTROOT)$(Install_Prefix)
RC_Install_Man    = $(DSTROOT)$(Install_Man)
RC_Install_Info   = $(DSTROOT)$(Install_Info)

ifndef Configure
Configure = $(Sources)/configure
endif

Configure_Flags = --prefix="$(Install_Prefix)"	\
		  --mandir="$(Install_Man)"	\
		  --infodir="$(Install_Info)"	\
		  $(Extra_Configure_Flags)

Install_Flags   = prefix="$(RC_Install_Prefix)"	\
		  mandir="$(RC_Install_Man)"	\
		  infodir="$(RC_Install_Info)"	\
		  $(Extra_Install_Flags)

##
# Targets
##

.PHONY: configure almostclean

install:: build
ifneq ($(GnuNoInstall),YES)
	@echo "Installing $(Project)..."
	$(_v) umask $(Install_Mask) ; $(MAKE) -C "$(BuildDirectory)" $(Install_Flags) $(Environment) install
	$(_v) $(FIND) "$(DSTROOT)" $(Find_Cruft) | $(XARGS) $(RMDIR)
	$(_v) $(FIND) "$(SYMROOT)" $(Find_Cruft) | $(XARGS) $(RMDIR)
ifneq ($(GnuNoChown),YES)
	$(_v)- $(CHOWN) -R $(Install_User).$(Install_Group) "$(DSTROOT)" "$(SYMROOT)"
endif
endif
ifdef GnuAfterInstall
	$(_v) $(MAKE) $(GnuAfterInstall)
endif

build:: configure
ifneq ($(GnuNoBuild),YES)
	@echo "Building $(Project)..."
	$(_v) $(MAKE) -C "$(BuildDirectory)" $(Environment)
endif

configure:: lazy_installsrc $(ConfigStamp)

$(ConfigStamp):
ifneq ($(GnuNoConfigure),YES)
	@echo "Configuring $(Project)..."
	$(_v) $(MKDIR) "$(BuildDirectory)"
	$(_v) $(Environment) cd "$(BuildDirectory)" && "$(Configure)" $(Configure_Flags)
endif
	$(_v) touch $@

almostclean::
ifneq ($(GnuNoClean),YES)
	@echo "Cleaning $(Project)..."
	$(_v) $(MAKE) -C "$(BuildDirectory)" clean
endif
