##
# Makefile for Making Rhapsody Installer Packages
# Wilfredo Sanchez | wsanchez@apple.com
# Copyright 1997 Apple Computer, Inc.
##
# This is meant for installing a project as one package.
# If you want multiple packages, you will need multiple Makefiles
#  (and multiple invocations of make).
# Alternatively, you can so some hackery like the source package below.
# The whole create_package business should probably be done as a shell
#  script or something more useful than a make target.
##
# Override these variables as needed, then include this file.
#
#  Package                   [ UNTITLED_PACKAGE                         ]
#  SourcePackage             [ $(Package)-source                        ]
#  Package_Source            [ /dev/null                                ]
#  SourcePackage_Source      [ $(shell pwd)                             ]
#  Package_Info              [ $(Package_Source)/$(Package).info        ]
#  SourcePackage_Info        [ $(Package_Source)/$(Package)-source.info ]
#  Package_Tiff              [ $(Package_Source)/$(Package).tiff        ]
#  SourcePackage_Tiff        [ $(Package_Tiff)                          ]
#  Package_Destination       [ /tmp                                     ]
#  SourcePackage_Destination [ $(Package_Destination)                   ]
##

##
# My Variables
##

ifndef Package
Package = UNTITLED_PACKAGE
endif

ifndef SourcePackage
SourcePackage = $(Package)-source
endif

ifndef Package_Source
Package_Source = /dev/null
endif

ifndef SourcePackage_Source
SourcePackage_Source = $(shell pwd)
endif

ifndef Package_Info
Package_Info = $(Package_Source)/$(Package).info
endif

ifndef SourcePackage_Info
SourcePackage_Info = $(SourcePackage_Source)/$(Package)-source.info
endif

ifndef Package_Tiff
Package_Tiff = $(Package_Source)/$(Package).tiff
endif

ifndef SourcePackage_Tiff
SourcePackage_Tiff = $(Package_Tiff)
endif

ifndef Package_Destination
Package_Destination = /tmp
endif

ifndef SourcePackage_Destination
SourcePackage_Destination = $(Package_Destination)
endif

Package_Bundle   = $(Package_Destination)/$(Package).pkg
Package_Tarfile  = $(Package_Bundle)/$(Package).tar.gz
Package_Info_Out = $(Package_Bundle)/$(Package).info
Package_Tiff_Out = $(Package_Bundle)/$(Package).tiff
Package_BOM      = $(Package_Bundle)/$(Package).bom
Package_Sizes    = $(Package_Bundle)/$(Package).sizes

##
# Targets
##

.PHONY: package source_package lazy_create_package create_package

packages:: source_package package

package:: lazy_create_package

source_package::
	$(_v) $(MAKE) lazy_create_package				\
			Package=$(SourcePackage)			\
			Package_Source='$$(SourcePackage_Source)'	\
			Package_Info=$(SourcePackage_Info)		\
			Package_Tiff=$(Package_Tiff)			\
			COPY_SOURCES=YES

lazy_create_package: $(Package_Tarfile) $(Package_Info_Out) $(Package_BOM) $(Package_Sizes)

$(Package_Tarfile) $(Package_Info_Out) $(Package_BOM) $(Package_Sizes): $(Package_Info) create_package

create_package: $(Package_Source) $(Package_Info)
	@echo 'Packaging $(Package_Source) as $(Package_Bundle)...'
	$(_v) $(RMDIR) $(Package_Bundle)
	$(_v) $(MKDIR) $(Package_Bundle)
	$(_v) cd $(Package_Source) && 						\
	      $(TAR) --owner=$(Install_User) --group=$(Install_Group) -cf - . |	\
	      $(GZIP) -c > $(Package_Tarfile)
	$(_v) $(CP) $(Package_Info) $(Package_Info_Out)
	$(_v)- $(CP) $(Package_Tiff) $(Package_Tiff_Out)
	$(_v) $(MKBOM) $(Package_Source) $(Package_BOM)
	@echo "Package contents:"
	@$(LSBOM) $(Package_BOM)
	$(_v) (											   \
	        file_count=`$(LSBOM) -s $(Package_BOM) | $(WC) -l`				&& \
	        compressed_size=$$((`$(DU) -s $(Package_BOM)   | $(AWK) '{print $$1}'`+3))	&& \
	              info_size=`$(LS) -s $(Package_Info_Out)  | $(AWK) '{print $$1}'`		&& \
	               bom_size=`$(LS) -s $(Package_BOM)       | $(AWK) '{print $$1}'`		&& \
		if [ -f $(Package_Tiff_Out) ]; then						   \
	          tiff_size=`$(LS) -s $(Package_Tiff_Out) | $(AWK) '{print $$1}'`;		   \
	        else										   \
	          tiff_size="0";								   \
	        fi										&& \
	        installed_size=$$((`$(DU) -s $(Package_Source) | $(AWK) '{print $$1}'`		   \
	                       +$$installed_size+$$info_size+$$bom_size+$$tiff_size+3))		&& \
	        echo "NumFiles $$file_count"            >  $(Package_Sizes)			&& \
	        echo "InstalledSize $$installed_size"   >> $(Package_Sizes)			&& \
	        echo "CompressedSize $$compressed_size" >> $(Package_Sizes)			&& \
	        echo "$$file_count files:"							&& \
	        echo "      $$compressed_size bytes compressed"					&& \
	        echo "      $$installed_size bytes uncompressed"				&& \
	      )
	$(_v)                                     $(TOUCH) $(Package_Tarfile)
	$(_v)                                     $(TOUCH) $(Package_Info_Out)
	$(_v) if [ -f $(Package_Tiff_Out) ]; then $(TOUCH) $(Package_Tiff_Out); fi
	$(_v)                                     $(TOUCH) $(Package_BOM)
	$(_v)                                     $(TOUCH) $(Package_Sizes)
	$(_v)  $(CHMOD) 444 $(Package_Tarfile)
	$(_v)  $(CHMOD) 444 $(Package_Info_Out)
	$(_v)- $(CHMOD) 444 $(Package_Tiff_Out)
	$(_v)  $(CHMOD) 444 $(Package_BOM)
	$(_v)  $(CHMOD) 444 $(Package_Sizes)
